==> haskell-pandoc-types-1.17.5.4-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.17.5.4
id: pandoc-types-1.17.5.4-5x7mKn8yuN0AmCCMtFntQ3
key: pandoc-types-1.17.5.4-5x7mKn8yuN0AmCCMtFntQ3
license: BSD-3-Clause
copyright: (c) 2006-2017 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://johnmacfarlane.net/pandoc
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
abi: 9b8c9be849caca9709a586c2dee220fb
exposed: True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk
hidden-modules: Paths_pandoc_types
import-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-types-1.17.5.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-types-1.17.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pandoc-types-1.17.5.4
hs-libraries: HSpandoc-types-1.17.5.4-5x7mKn8yuN0AmCCMtFntQ3
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.3.0-2f2DWYxbnUnFm9iFQHaKmb base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    ghc-prim-0.5.3 syb-0.7-KRW1LCxdMiCJrmhxCvzo37 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.17.5.4-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.17.5.4
id: pandoc-types-1.17.5.4-KgGurLsdVvTHNZtMP40vgX
key: pandoc-types-1.17.5.4-KgGurLsdVvTHNZtMP40vgX
license: BSD-3-Clause
copyright: (c) 2006-2017 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://johnmacfarlane.net/pandoc
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
abi: 8062595ae3e6ae009d28ecc092bd3742
exposed: True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk
hidden-modules: Paths_pandoc_types
import-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-types-1.17.5.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-types-1.17.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pandoc-types-1.17.5.4
hs-libraries: HSpandoc-types-1.17.5.4-KgGurLsdVvTHNZtMP40vgX
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.3.0-5u6hknCeN6OEP5DlN5W0LL base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    ghc-prim-0.5.3 syb-0.7-KRW1LCxdMiCJrmhxCvzo37 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
